==> yabs-0.7.1.tar.bz2: yabs/admin/ftb.sub.php <==
<?php

	if($_SESSION['right'][RIGHT_FEEDBACK]){
		$query = array();
		
		if(isset($_POST['delete'])){
			$tpl->add_tpl('admin/empty.tpl');
			if(isset($_POST['ID']) && count($_POST['ID'])){
				$echo = "";
				foreach($_POST['ID'] as $trackback){
					if(is_numeric($trackback)){
						$sql = "SELECT
									BlogID
								FROM
									".$dbprefix."trackback
								WHERE
									Id = '".$trackback."';";
						$res = $db->query($sql);
						if($db->numrows($res)){
							$row = $db->fetch($res);
							$del_sql = "DELETE FROM
											".$dbprefix."trackback
										WHERE
											ID = '".$trackback."';";
							$db->query($del_sql);
							$yabs->deletecachedentry($row['ID']);
							$echo .= str_replace('{N}', $trackback, $lang['admin_feedback_deleted']);
						}
					}
				}
				$query['admin'] = 'ftb';
				$echo .= '<a href="'.url_admin($query).'">'.$lang['continue'].'</a>';
				$tpl->fillin('CONTENT', $echo);
			}else{
				$tpl->fillin('CONTENT', $lang['admin_error_noid'].$lang['back']);
			}
		}elseif(isset($_POST['activate'])){
			$tpl->add_tpl('admin/empty.tpl');
			if(isset($_POST['ID']) && count($_POST['ID'])){
				$echo = "";
				foreach($_POST['ID'] as $trackback){
					if(is_numeric($trackback)){
						$com_sql = "SELECT
										BlogID,
										active
									FROM
										".$dbprefix."trackback
									WHERE
										ID = '".$trackback."'";
						$com_res = $db->query($com_sql);
						if($db->numrows($com_res)){
							$com_row = $db->fetch($com_res);
							if($com_row['active']){
								$com_sql = "UPDATE
												".$dbprefix."trackback
											SET
												active = '0'
											WHERE
												ID = '".$trackback."';";
								$db->query($com_sql);
								$echo .= str_replace('{N}', $trackback, $lang['admin_feedback_deactivated']);
							}else{
								$com_sql = "UPDATE
												".$dbprefix."trackback
											SET
												active = '1'
											WHERE
												ID = '".$trackback."';";
								$db->query($com_sql);
								$echo .= str_replace('{N}', $trackback, $lang['admin_feedback_activated']);
							}
							$yabs->deletecachedentry($com_row['BlogID']);
						}
					}
				}
				$query['admin'] = 'ftb';
				$echo .= '<a href="'.url_admin($query).'">'.$lang['continue'].'</a>';
				$tpl->fillin('CONTENT', $echo);
			}else{
				$tpl->fillin('CONTENT', $lang['admin_error_noid'].$lang['back']);
			}
		}else{
			if(isset($_GET['action']) && $_GET['action'] = 'info'){
				if(isset($_GET['id']) && is_numeric($_GET['id'])){
					$com_sql = "SELECT
									*
								FROM
									".$dbprefix."trackback
								WHERE
									ID = '".$_GET['id']."';";
					$com_res = $db->query($com_sql);
					if($db->numrows($com_res)){
						$com_row = $db->fetch($com_res);
						$tpl->add_tpl('admin/feedback_info.tpl');
						$tpl->fillin('COMMENT', '<b>'.blank_text($com_row['title']).'</b><br />'.blank_text($com_row['excerpt']));
						$tpl->fillin('COMMENT_EMAIL', '');
						$tpl->fillin('COMMENT_IP', $com_row['IP']);
						$tpl->fillin('COMMENT_HP', $com_row['url']);
						$tpl->fillin('BACK', $lang['back']);
						$tpl->fillin('COMMENT_ID', $com_row['ID']);
						$tpl->fillin('COMMENT_AUTOR', $com_row['blog_name']);
						$tpl->fillin('COMMENT_DATE', strftime('%m-%d-%Y %H:%M', $com_row['date']));
						$tpl->fillin('HP', $lang['form_hp']);
						$tpl->fillin('ID', $lang['form_id']);
						$tpl->fillin('AUTOR', $lang['form_autor']);
						$tpl->fillin('EMAIL', '');
						$tpl->fillin('IP', $lang['form_ip']);
						$tpl->fillin('DATE', $lang['form_date']);
						$query = array();
						$query['site'] = 'blog';
						$query['entry'] = $com_row['BlogID'];
						$tpl->fillin('LINK_ORIGINAL_ENTRY', '<a href="'.url($query).'">'.$lang['goto_entry'].'</a>');
					}else{
						$tpl->add_tpl('admin/empty.tpl');
						$tpl->fillin('CONTENT', $lang['admin_error_nocomment'].$lang['back']);
					}		
				}else{
					$tpl->add_tpl('admin/empty.tpl');
					$tpl->fillin('CONTENT', $lang['admin_error_noid'].$lang['back']);
				}
			}else{
				$tpl->add_tpl('admin/feedback.tpl');
				$query['admin'] = 'ftb';
				$tpl->fillin('ACTION', url_admin($query));
				
				if(isset($_GET['offset']) && is_numeric($_GET['offset'])) $offset = $_GET['offset'];
				else $offset = 0;
				$list_sql = "	SELECT
									ID,
									title,
									date,
									active
								FROM
									".$dbprefix."trackback
								ORDER BY
									date DESC
								LIMIT
									".$offset.", 30;";
				$list_res = $db->query($list_sql);
				$fillin = $tpl->parse_explodes(1);
				$finalecho = "";
				$query = array();
				$query['admin'] = 'ftb';
				$query['action'] = 'info';
				while($list = $db->fetch($list_res)){
					$echo = $tpl->fillin_explode('INPUT_ID', '<input type="checkbox" name="ID[]" value="'.$list['ID'].'" />', $fillin);
					$query['id'] = $list['ID'];
					$echo = $tpl->fillin_explode('ENTRY_TITLE', '<a href="'.url_admin($query).'">'.changetext($list['title']).'</a>', $echo);
					$echo = $tpl->fillin_explode('ENTRY_DATE', strftime('%m-%d-%Y %H:%M', $list['date']), $echo);
					if($list['active']){
						$echo = $tpl->fillin_explode('ENTRY_ACTIVE', $lang['admin_entry_active'], $echo);
					}else{
						$echo = $tpl->fillin_explode('ENTRY_ACTIVE', $lang['admin_entry_inactive'], $echo);
					}
					$finalecho .= $echo;
				}
				$tpl->replace_array($finalecho, 1);
				$tpl->parse_implode();
				
				$tpl->fillin('FORM_TITLE', $lang['admin_form_title']);
				$tpl->fillin('FORM_DATE', $lang['admin_form_date']);
				$tpl->fillin('FORM_ACTIVE', $lang['admin_form_active']);
				$tpl->fillin('INPUT_ACTIVATE', '<input type="submit" name="activate" value="'.$lang['admin_activate'].'" />');
				$tpl->fillin('INPUT_DELETE', '<input type="submit" name="delete" value="'.$lang['admin_delete'].'" />');
				
				//$query['action'] = 'list';
				if($db->numrows($list_res) == 30){
						$query['offset'] = $offset + 30;
						$tpl->fillin('OLDER_ENTRIES', "<a href=\"".url_admin($query)."\">".$lang['older_entries']."</a>");
				}else{
					$tpl->fillin('OLDER_ENTRIES', '');
				}
				if($offset > 0){
					$offset_newer = $offset - 30;
					if($offset_newer < 0) $offset_newer = 0;
					$query['offset'] = $offset_newer;
					$tpl->fillin('NEWER_ENTRIES', "<a href=\"".url_admin($query)."\">".$lang['newer_entries']."</a>");
				}else{
					$tpl->fillin('NEWER_ENTRIES', '');
				}
			}
		}
	}else{
		$tpl->add_tpl('admin/empty.tpl');
		$tpl->fillin('CONTENT', $lang['admin_error_access_denied'].$lang['back']);
	}	
?>

==> yabs-0.7.3.tar.bz2: yabs/admin/ftb.sub.php <==
<?php

	if($_SESSION['right'][RIGHT_FEEDBACK]){
		$query = array();
		
		if(isset($_POST['delete'])){
			$tpl->add_tpl('admin/empty.tpl');
			if(isset($_POST['ID']) && count($_POST['ID'])){
				$echo = "";
				foreach($_POST['ID'] as $trackback){
					if(is_numeric($trackback)){
						$sql = "SELECT
									BlogID
								FROM
									".$dbprefix."trackback
								WHERE
									Id = '".$trackback."';";
						$res = $db->query($sql);
						if($db->numrows($res)){
							$row = $db->fetch($res);
							$del_sql = "DELETE FROM
											".$dbprefix."trackback
										WHERE
											ID = '".$trackback."';";
							$db->query($del_sql);
							$yabs->deletecachedentry($row['BlogID']);
							$echo .= str_replace('{N}', $trackback, $lang['admin_feedback_deleted']);
						}
					}
				}
				$query['admin'] = 'ftb';
				$echo .= '<a href="'.url_admin($query).'">'.$lang['continue'].'</a>';
				$tpl->fillin('CONTENT', $echo);
			}else{
				$tpl->fillin('CONTENT', $lang['admin_error_noid'].$lang['back']);
			}
		}elseif(isset($_POST['activate'])){
			$tpl->add_tpl('admin/empty.tpl');
			if(isset($_POST['ID']) && count($_POST['ID'])){
				$echo = "";
				foreach($_POST['ID'] as $trackback){
					if(is_numeric($trackback)){
						$com_sql = "SELECT
										BlogID,
										active
									FROM
										".$dbprefix."trackback
									WHERE
										ID = '".$trackback."'";
						$com_res = $db->query($com_sql);
						if($db->numrows($com_res)){
							$com_row = $db->fetch($com_res);
							if($com_row['active']){
								$com_sql = "UPDATE
												".$dbprefix."trackback
											SET
												active = '0'
											WHERE
												ID = '".$trackback."';";
								$db->query($com_sql);
								$echo .= str_replace('{N}', $trackback, $lang['admin_feedback_deactivated']);
							}else{
								$com_sql = "UPDATE
												".$dbprefix."trackback
											SET
												active = '1'
											WHERE
												ID = '".$trackback."';";
								$db->query($com_sql);
								$echo .= str_replace('{N}', $trackback, $lang['admin_feedback_activated']);
							}
							$yabs->deletecachedentry($com_row['BlogID']);
						}
					}
				}
				$query['admin'] = 'ftb';
				$echo .= '<a href="'.url_admin($query).'">'.$lang['continue'].'</a>';
				$tpl->fillin('CONTENT', $echo);
			}else{
				$tpl->fillin('CONTENT', $lang['admin_error_noid'].$lang['back']);
			}
		}else{
			if(isset($_GET['action']) && $_GET['action'] = 'info'){
				if(isset($_GET['id']) && is_numeric($_GET['id'])){
					$com_sql = "SELECT
									*
								FROM
									".$dbprefix."trackback
								WHERE
									ID = '".$_GET['id']."';";
					$com_res = $db->query($com_sql);
					if($db->numrows($com_res)){
						$com_row = $db->fetch($com_res);
						$tpl->add_tpl('admin/feedback_info.tpl');
						$tpl->fillin('COMMENT', '<b>'.blank_text($com_row['title']).'</b><br />'.blank_text($com_row['excerpt']));
						$tpl->fillin('COMMENT_EMAIL', '');
						$tpl->fillin('COMMENT_IP', $com_row['IP']);
						$tpl->fillin('COMMENT_HP', $com_row['url']);
						$tpl->fillin('BACK', $lang['back']);
						$tpl->fillin('COMMENT_ID', $com_row['ID']);
						$tpl->fillin('COMMENT_AUTOR', $com_row['blog_name']);
						$tpl->fillin('COMMENT_DATE', strftime('%m-%d-%Y %H:%M', $com_row['date']));
						$tpl->fillin('HP', $lang['form_hp']);
						$tpl->fillin('ID', $lang['form_id']);
						$tpl->fillin('AUTOR', $lang['form_autor']);
						$tpl->fillin('EMAIL', '');
						$tpl->fillin('IP', $lang['form_ip']);
						$tpl->fillin('DATE', $lang['form_date']);
						$query = array();
						$query['site'] = 'blog';
						$query['entry'] = $com_row['BlogID'];
						$tpl->fillin('LINK_ORIGINAL_ENTRY', '<a href="'.url($query).'">'.$lang['goto_entry'].'</a>');
					}else{
						$tpl->add_tpl('admin/empty.tpl');
						$tpl->fillin('CONTENT', $lang['admin_error_nocomment'].$lang['back']);
					}		
				}else{
					$tpl->add_tpl('admin/empty.tpl');
					$tpl->fillin('CONTENT', $lang['admin_error_noid'].$lang['back']);
				}
			}else{
				$tpl->add_tpl('admin/feedback.tpl');
				$query['admin'] = 'ftb';
				$tpl->fillin('ACTION', url_admin($query));
				
				if(isset($_GET['offset']) && is_numeric($_GET['offset'])) $offset = $_GET['offset'];
				else $offset = 0;
				$list_sql = "	SELECT
									ID,
									title,
									date,
									active
								FROM
									".$dbprefix."trackback
								ORDER BY
									date DESC
								LIMIT
									".$offset.", 30;";
				$list_res = $db->query($list_sql);
				$fillin = $tpl->parse_explodes(1);
				$finalecho = "";
				$query = array();
				$query['admin'] = 'ftb';
				$query['action'] = 'info';
				while($list = $db->fetch($list_res)){
					$echo = $tpl->fillin_explode('INPUT_ID', '<input type="checkbox" name="ID[]" value="'.$list['ID'].'" />', $fillin);
					$query['id'] = $list['ID'];
					$echo = $tpl->fillin_explode('ENTRY_TITLE', '<a href="'.url_admin($query).'">'.changetext($list['title']).'</a>', $echo);
					$echo = $tpl->fillin_explode('ENTRY_DATE', strftime('%m-%d-%Y %H:%M', $list['date']), $echo);
					if($list['active']){
						$echo = $tpl->fillin_explode('ENTRY_ACTIVE', $lang['admin_entry_active'], $echo);
					}else{
						$echo = $tpl->fillin_explode('ENTRY_ACTIVE', $lang['admin_entry_inactive'], $echo);
					}
					$finalecho .= $echo;
				}
				$tpl->replace_array($finalecho, 1);
				$tpl->parse_implode();
				
				$tpl->fillin('FORM_TITLE', $lang['admin_form_title']);
				$tpl->fillin('FORM_DATE', $lang['admin_form_date']);
				$tpl->fillin('FORM_ACTIVE', $lang['admin_form_active']);
				$tpl->fillin('INPUT_ACTIVATE', '<input type="submit" name="activate" value="'.$lang['admin_activate'].'" />');
				$tpl->fillin('INPUT_DELETE', '<input type="submit" name="delete" value="'.$lang['admin_delete'].'" />');
				
				//$query['action'] = 'list';
				$query = array();
				$query['admin'] = 'ftb';
				if($db->numrows($list_res) == 30){
						$query['offset'] = $offset + 30;
						$tpl->fillin('OLDER_ENTRIES', "<a href=\"".url_admin($query)."\">".$lang['older_entries']."</a>");
				}else{
					$tpl->fillin('OLDER_ENTRIES', '');
				}
				if($offset > 0){
					$offset_newer = $offset - 30;
					if($offset_newer < 0) $offset_newer = 0;
					$query['offset'] = $offset_newer;
					$tpl->fillin('NEWER_ENTRIES', "<a href=\"".url_admin($query)."\">".$lang['newer_entries']."</a>");
				}else{
					$tpl->fillin('NEWER_ENTRIES', '');
				}
			}
		}
	}else{
		$tpl->add_tpl('admin/empty.tpl');
		$tpl->fillin('CONTENT', $lang['admin_error_access_denied'].$lang['back']);
	}	
?>
